@@ -284,15 +284,20 @@ class RuleBorda(Rule):
     Jessica Davies, George Katsirelos, Nina Narodytska, Toby Walsh and Lirong Xia, 2014.
     """
 
+    full_name = 'Borda'
+    abbreviation = 'Bor'
+
+    options_parameters = Rule.options_parameters.copy()
+    options_parameters.update({
+        'im_option': {'allowed': ['exact'], 'default': 'exact'},
+        'tm_option': {'allowed': ['exact'], 'default': 'exact'},
+        'um_option': {'allowed': ['exact'], 'default': 'exact'},
+        'icm_option': {'allowed': ['fast'], 'default': 'fast'},
+        'cm_option': {'allowed': ['fast', 'exact'], 'default': 'fast'},
+    })
+
     def __init__(self, **kwargs):
         super().__init__(
-            options_parameters={
-                'im_option': {'allowed': ['exact'], 'default': 'exact'},
-                'tm_option': {'allowed': ['exact'], 'default': 'exact'},
-                'um_option': {'allowed': ['exact'], 'default': 'exact'},
-                'icm_option': {'allowed': ['fast'], 'default': 'fast'},
-                'cm_option': {'allowed': ['fast', 'exact'], 'default': 'fast'},
-            },
             with_two_candidates_reduces_to_plurality=True, is_based_on_rk=True,
             precheck_icm=False, log_identity="BORDA", **kwargs
         )
